from setuptools import setup

setup(
    name='cf_compare_versions',
    version='0.0.1',
    packages=['compare_versions'],
    url='https://github.com/carlos-ferras/code-challenge/compare_versions',
    license='MIT',
    author='Carlos Ferras',
    author_email='c4rlos.ferra5@gmail.com',
    description='Compare version strings',
    long_description=open("README.md", "r").read(),
    long_description_content_type="text/markdown"
)
